@@ -12,8 +12,9 @@ use Perinci::Util qw(get_package_meta_accessor);
 use Scalar::Util qw(blessed reftype);
 use SHARYANTO::Package::Util qw(package_exists);
 use URI;
+use UUID::Random;
 
-our $VERSION = '0.33'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 our $re_mod = qr/\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_][A-Za-z_0-9]*)*\z/;
 
@@ -386,6 +387,7 @@ sub action_call {
             $args{-dry_run} = 1;
         } else {
             $args{-tx_action} = 'check_state';
+            $args{-tx_action_id} = UUID::Random::generate();
             undef $tm;
         }
     }
@@ -730,7 +732,7 @@ Perinci::Access::InProcess - Use Rinci access protocol (Riap) to access Perl cod
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
